@@ -16,12 +16,11 @@ import platform
 import sys
 
 # Pip imports
-from body import access, errors, users
+from body import errors
 from RestOC import Conf, EMail, Record_MySQL, REST, Services, Session
 
 # Module imports
-from . import Brain
-from . import records
+from . import access, Brain, records, users
 
 def cli():
 	"""CLI
